==> haskell-sdl2-ttf-2.1.3-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sdl2-ttf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 sdl2-ttf
version:              2.1.3
visibility:           public
id:                   sdl2-ttf-2.1.3-Dp5YJV7nAExC5BsMksiiA3
key:                  sdl2-ttf-2.1.3-Dp5YJV7nAExC5BsMksiiA3
license:              BSD-3-Clause
copyright:
    Copyright © 2013-2022 Ömer Sinan Ağacan, Siniša Biđin, Rongcui Dong and others (see git commits)

maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:
    Rongcui Dong (rongcuid@outlook.com),
    Siniša Biđin <sinisa@bidin.eu>,
    Ömer Sinan Ağacan (omeragacan@gmail.com),
    Sean Chalmers (sclhiannan@gmail.com)

synopsis:             Bindings to SDL2_ttf.
description:
    Haskell bindings to SDL2_ttf C++ library <https://github.com/libsdl-org/SDL_ttf>.

category:             Font, Foreign binding, Graphics
abi:                  d154955167cb3c556a5e68fbe42026c0
exposed:              True
exposed-modules:      SDL.Font SDL.Raw.Font
hidden-modules:       SDL.Raw.Helper
import-dirs:          /usr/lib/ghc-9.0.2/site-local/sdl2-ttf-2.1.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/sdl2-ttf-2.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sdl2-ttf
hs-libraries:         HSsdl2-ttf-2.1.3-Dp5YJV7nAExC5BsMksiiA3
extra-libraries:      SDL2_ttf SDL2
include-dirs:         /usr/include/SDL2
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    sdl2-2.5.4.0-8YowiiHGvxLEOWq4KplLJi template-haskell-2.17.0.0
    text-1.2.5.0 th-abstraction-0.4.5.0-CPrpKcr2W2S31K8QsJKgDp
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-sdl2-ttf/html/sdl2-ttf.haddock
haddock-html:         /usr/share/doc/haskell-sdl2-ttf/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sdl2-ttf-2.1.3-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sdl2-ttf.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 sdl2-ttf
version:              2.1.3
visibility:           public
id:                   sdl2-ttf-2.1.3-5yYrNtGXoMY1NHSIXL3WAX
key:                  sdl2-ttf-2.1.3-5yYrNtGXoMY1NHSIXL3WAX
license:              BSD-3-Clause
copyright:
    Copyright © 2013-2022 Ömer Sinan Ağacan, Siniša Biđin, Rongcui Dong and others (see git commits)

maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:
    Rongcui Dong (rongcuid@outlook.com),
    Siniša Biđin <sinisa@bidin.eu>,
    Ömer Sinan Ağacan (omeragacan@gmail.com),
    Sean Chalmers (sclhiannan@gmail.com)

synopsis:             Bindings to SDL2_ttf.
description:
    Haskell bindings to SDL2_ttf C++ library <https://github.com/libsdl-org/SDL_ttf>.

category:             Font, Foreign binding, Graphics
abi:                  963831892090ea45547690e4ee73272f
exposed:              True
exposed-modules:      SDL.Font SDL.Raw.Font
hidden-modules:       SDL.Raw.Helper
import-dirs:          /usr/lib/ghc-9.0.2/site-local/sdl2-ttf-2.1.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/sdl2-ttf-2.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sdl2-ttf
hs-libraries:         HSsdl2-ttf-2.1.3-5yYrNtGXoMY1NHSIXL3WAX
extra-libraries:      SDL2_ttf SDL2
include-dirs:         /usr/include/SDL2
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    sdl2-2.5.4.0-E8U5IUPjKpnAhKNTlugUbH template-haskell-2.17.0.0
    text-1.2.5.0 th-abstraction-0.4.5.0-CPrpKcr2W2S31K8QsJKgDp
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-sdl2-ttf/html/sdl2-ttf.haddock
haddock-html:         /usr/share/doc/haskell-sdl2-ttf/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
